;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "elisp-dev-mcp" "20260602.1123"
  "MCP server for agentic Elisp development."
  '((emacs          "27.1")
    (mcp-server-lib "0.4.0"))
  :url "https://github.com/laurynas-biveinis/elisp-dev-mcp"
  :commit "6120460212e03daf2f9502c3a5cebab958faa419"
  :revdesc "6120460212e0"
  :keywords '("tools" "development"))
